@@ -7,6 +7,8 @@
 extern crate alloc;
 
 pub mod eth;
+#[cfg(feature = "experimental")]
+pub mod event_bus;
 #[cfg(all(feature = "experimental", feature = "alloc"))]
 pub mod http;
 #[cfg(feature = "std")] // TODO: Lower requirements to "alloc"
@@ -21,6 +23,9 @@ pub mod ota;
 pub mod ping;
 #[cfg(feature = "alloc")]
 pub mod storage;
+pub mod sys_time;
+#[cfg(feature = "experimental")]
+pub mod timer;
 pub mod utils;
 #[cfg(feature = "alloc")]
 pub mod wifi;
