@@ -10,7 +10,7 @@ use enumset::*;
 use serde::{Deserialize, Serialize};
 
 #[cfg(feature = "use_strum")]
-use strum_macros::{EnumIter, EnumMessage, EnumString, ToString};
+use strum_macros::{Display, EnumIter, EnumMessage, EnumString};
 
 #[cfg(feature = "use_numenum")]
 use num_enum::TryFromPrimitive;
@@ -23,7 +23,7 @@ use crate::ipv4;
 #[cfg_attr(feature = "use_serde", derive(Serialize, Deserialize))]
 #[cfg_attr(
     feature = "use_strum",
-    derive(EnumString, ToString, EnumMessage, EnumIter)
+    derive(EnumString, Display, EnumMessage, EnumIter)
 )]
 #[cfg_attr(feature = "use_numenum", derive(TryFromPrimitive))]
 #[cfg_attr(feature = "use_numenum", repr(u8))]
@@ -76,7 +76,7 @@ impl Default for AuthMethod {
 #[cfg_attr(feature = "use_serde", derive(Serialize, Deserialize))]
 #[cfg_attr(
     feature = "use_strum",
-    derive(EnumString, ToString, EnumMessage, EnumIter)
+    derive(EnumString, Display, EnumMessage, EnumIter)
 )]
 #[cfg_attr(feature = "use_numenum", derive(TryFromPrimitive))]
 #[cfg_attr(feature = "use_numenum", repr(u8))]
@@ -118,7 +118,7 @@ impl Default for Protocol {
 #[cfg_attr(feature = "use_serde", derive(Serialize, Deserialize))]
 #[cfg_attr(
     feature = "use_strum",
-    derive(EnumString, ToString, EnumMessage, EnumIter)
+    derive(EnumString, Display, EnumMessage, EnumIter)
 )]
 #[cfg_attr(feature = "use_numenum", derive(TryFromPrimitive))]
 #[cfg_attr(feature = "use_numenum", repr(u8))]
@@ -251,7 +251,7 @@ impl Default for ClientConfiguration {
 #[cfg_attr(feature = "use_serde", derive(Serialize, Deserialize))]
 #[cfg_attr(
     feature = "use_strum",
-    derive(EnumString, ToString, EnumMessage, EnumIter)
+    derive(EnumString, Display, EnumMessage, EnumIter)
 )]
 #[cfg_attr(feature = "use_numenum", derive(TryFromPrimitive))]
 #[cfg_attr(feature = "use_numenum", repr(u8))]
